/*
 * decollector_i.h
 * Collector private header file.
 *
 * Copyright (C) 2020-2023 IOPSYS Software Solutions AB. All rights reserved.
 *
 * See LICENSE file for license related information.
 */

#ifndef DECOLLECTOR_I_H
#define DECOLLECTOR_I_H

#include "timer.h"
#include <stdint.h>


struct getter_txn {
	uint8_t cnt;
	uint16_t request;
	uint16_t expect;
};

enum getter_state {
	GT_IDLE = 0,
	GT_RUNNING,
	GT_DONE,
};

extern struct getter_txn txnlist[];
#define NUM_TXN		11

struct getter_context {
	time_t start;
	time_t end;
	atimer_t t;
	uint32_t tmo;
	int retry;
	uint8_t state;
	int txni;
	struct getter_txn txn[NUM_TXN];
	uint32_t rxcnt[NUM_TXN];
	uint32_t error[NUM_TXN];
	uint16_t request;
	uint16_t expect;
	uint16_t last_sent_mid;
	void *collector;
	void *agent;
	uint32_t rbitmap;
};


int getter_next_request(struct getter_context *gt);
void getter_clear_expect(struct getter_context *gt, uint16_t cmdutype);
bool getter_expect_pending_any(struct getter_context *gt);
bool getter_expect_pending(struct getter_context *gt, uint16_t cmdutype);
void getter_update_error(struct getter_context *gt, uint16_t cmdutype);

#endif	/* DECOLLECTOR_I_H */
